@@ -1,4 +1,4 @@
-/* $OpenBSD: d1_pkt.c,v 1.41 2015/06/13 08:38:10 doug Exp $ */
+/* $OpenBSD: d1_pkt.c,v 1.45 2015/07/18 23:00:23 doug Exp $ */
 /*
  * DTLS implementation written by Nagendra Modadugu
  * (nagendra@cs.stanford.edu) for the OpenSSL project 2005.
@@ -124,6 +124,7 @@
 #include <openssl/evp.h>
 
 #include "pqueue.h"
+#include "bytestring.h"
 
 /* mod 128 saturating subtract of two 64-bit values in big-endian order */
 static int
@@ -464,11 +465,9 @@ err:
 int
 dtls1_get_record(SSL *s)
 {
-	int ssl_major, ssl_minor;
 	int i, n;
 	SSL3_RECORD *rr;
 	unsigned char *p = NULL;
-	unsigned short version;
 	DTLS1_BITMAP *bitmap;
 	unsigned int is_next_epoch;
 
@@ -484,64 +483,68 @@ dtls1_get_record(SSL *s)
 		return 1;
 
 	/* get something from the wire */
+	if (0) {
 again:
+		/* dump this record on all retries */
+		rr->length = 0;
+		s->packet_length = 0;
+	}
+
 	/* check if we have the header */
 	if ((s->rstate != SSL_ST_READ_BODY) ||
-		(s->packet_length < DTLS1_RT_HEADER_LENGTH)) {
+	    (s->packet_length < DTLS1_RT_HEADER_LENGTH)) {
+		CBS header, seq_no;
+		uint16_t epoch, len, ssl_version;
+		uint8_t type;
+
 		n = ssl3_read_n(s, DTLS1_RT_HEADER_LENGTH, s->s3->rbuf.len, 0);
 		/* read timeout is handled by dtls1_read_bytes */
 		if (n <= 0)
 			return(n); /* error or non-blocking */
 
 		/* this packet contained a partial record, dump it */
-		if (s->packet_length != DTLS1_RT_HEADER_LENGTH) {
-			s->packet_length = 0;
+		if (s->packet_length != DTLS1_RT_HEADER_LENGTH)
 			goto again;
-		}
 
 		s->rstate = SSL_ST_READ_BODY;
 
-		p = s->packet;
+		CBS_init(&header, s->packet, s->packet_length);
 
 		/* Pull apart the header into the DTLS1_RECORD */
-		rr->type= *(p++);
-		ssl_major= *(p++);
-		ssl_minor= *(p++);
-		version = (ssl_major << 8)|ssl_minor;
+		if (!CBS_get_u8(&header, &type))
+			goto again;
+		if (!CBS_get_u16(&header, &ssl_version))
+			goto again;
 
 		/* sequence number is 64 bits, with top 2 bytes = epoch */
-		n2s(p, rr->epoch);
-
-		memcpy(&(s->s3->read_sequence[2]), p, 6);
-		p += 6;
-
-		n2s(p, rr->length);
-
-		/* Lets check version */
-		if (!s->first_packet) {
-			if (version != s->version) {
-				/* unexpected version, silently discard */
-				rr->length = 0;
-				s->packet_length = 0;
-				goto again;
-			}
-		}
-
-		if ((version & 0xff00) != (s->version & 0xff00)) {
-			/* wrong version, silently discard record */
-			rr->length = 0;
-			s->packet_length = 0;
+		if (!CBS_get_u16(&header, &epoch) ||
+		    !CBS_get_bytes(&header, &seq_no, 6))
 			goto again;
-		}
 
-		if (rr->length > SSL3_RT_MAX_ENCRYPTED_LENGTH) {
-			/* record too long, silently discard it */
-			rr->length = 0;
-			s->packet_length = 0;
+		if (!CBS_write_bytes(&seq_no, &(s->s3->read_sequence[2]),
+		    sizeof(s->s3->read_sequence) - 2, NULL))
+			goto again;
+		if (!CBS_get_u16(&header, &len))
+			goto again;
+
+		rr->type = type;
+		rr->epoch = epoch;
+		rr->length = len;
+
+		/* unexpected version, silently discard */
+		if (!s->first_packet && ssl_version != s->version)
+			goto again;
+
+		/* wrong version, silently discard record */
+		if ((ssl_version & 0xff00) != (s->version & 0xff00))
+			goto again;
+
+		/* record too long, silently discard it */
+		if (rr->length > SSL3_RT_MAX_ENCRYPTED_LENGTH)
 			goto again;
-		}
 
 		/* now s->rstate == SSL_ST_READ_BODY */
+		p = (unsigned char *)CBS_data(&header);
 	}
 
 	/* s->rstate == SSL_ST_READ_BODY, get and decode the data */
@@ -554,11 +557,8 @@ again:
 			return(n); /* error or non-blocking io */
 
 		/* this packet contained a partial record, dump it */
-		if (n != i) {
-			rr->length = 0;
-			s->packet_length = 0;
+		if (n != i)
 			goto again;
-		}
 
 		/* now n == rr->length,
 		 * and s->packet_length == DTLS1_RT_HEADER_LENGTH + rr->length */
@@ -567,13 +567,8 @@ again:
 
 	/* match epochs.  NULL means the packet is dropped on the floor */
 	bitmap = dtls1_get_bitmap(s, rr, &is_next_epoch);
-	if (bitmap == NULL) {
-		rr->length = 0;
-		s->packet_length = 0;
-		/* dump this record */
+	if (bitmap == NULL)
 		goto again;
-		/* get another record */
-	}
 
 	/*
 	 * Check whether this is a repeat, or aged record.
@@ -584,12 +579,8 @@ again:
 	 */
 	if (!(s->d1->listen && rr->type == SSL3_RT_HANDSHAKE &&
 	    p != NULL && *p == SSL3_MT_CLIENT_HELLO) &&
-	    !dtls1_record_replay_check(s, bitmap)) {
-		rr->length = 0;
-		s->packet_length=0; /* dump this record */
+	    !dtls1_record_replay_check(s, bitmap))
 		goto again;
-		/* get another record */
-	}
 
 	/* just read a 0 length packet */
 	if (rr->length == 0)
@@ -608,23 +599,16 @@ again:
 			/* Mark receipt of record. */
 			dtls1_record_bitmap_update(s, bitmap);
 		}
-		rr->length = 0;
-		s->packet_length = 0;
 		goto again;
 	}
 
-	if (!dtls1_process_record(s)) {
-		rr->length = 0;
-		s->packet_length = 0;
-		/* dump this record */
+	if (!dtls1_process_record(s))
 		goto again;
-		/* get another record */
-	}
+
 	/* Mark receipt of record. */
 	dtls1_record_bitmap_update(s, bitmap);
 
 	return (1);
-
 }
 
 /* Return up to 'len' payload bytes received in 'type' records.
@@ -1035,7 +1019,8 @@ start:
 		struct hm_header_st msg_hdr;
 
 		/* this may just be a stale retransmit */
-		dtls1_get_message_header(rr->data, &msg_hdr);
+		if (!dtls1_get_message_header(rr->data, &msg_hdr))
+			return -1;
 		if (rr->epoch != s->d1->r_epoch) {
 			rr->length = 0;
 			goto start;
